@@ -574,7 +574,7 @@ def test_callback():
 
     @responses.activate
     def run():
-        responses.add_callback(responses.GET, url, request_callback)
+        rsp = responses.add_callback(responses.GET, url, request_callback)
         resp = requests.get(url)
         assert resp.text == "test callback"
         assert resp.status_code == status
@@ -582,6 +582,7 @@ def test_callback():
         assert "bar" == resp.headers.get("foo")
         assert "application/json" == resp.headers.get("Content-Type")
         assert "13" == resp.headers.get("Content-Length")
+        assert len(rsp.calls) == 1
 
     run()
     assert_reset()
@@ -926,12 +927,12 @@ def test_activate_doesnt_change_signature():
 
 
 @pytest.fixture
-def my_fruit():  # type: ignore[misc]
+def my_fruit() -> str:
     return "apple"
 
 
 @pytest.fixture
-def fruit_basket(my_fruit):  # type: ignore[misc]
+def fruit_basket(my_fruit: str) -> "list[str]":
     return ["banana", my_fruit]
 
 
@@ -1333,7 +1334,7 @@ def test_handles_buffered_reader_body():
 
     @responses.activate
     def run():
-        responses.add(responses.GET, url, body=BufferedReader(BytesIO(b"test")))  # type: ignore
+        responses.add(responses.GET, url, body=BufferedReader(BytesIO(b"test")))
 
         resp = requests.get(url)
 
@@ -1558,7 +1559,7 @@ def test_auto_calculate_content_length_doesnt_work_for_buffered_reader_body():
         responses.add(
             responses.GET,
             url,
-            body=BufferedReader(BytesIO(b"testing")),  # type: ignore
+            body=BufferedReader(BytesIO(b"testing")),
             auto_calculate_content_length=True,
         )
         resp = requests.get(url)
